La ferme impossible
===================

Dans ce livre, Dominic Lamontagne partage les nombreux obstacles
réglementaires soumis à une ferme artisanale au Québec qui compte 2
vaches, 200 poules et 500 poulets. Ce sont les piliers de l'agriculture
régionale - le lait, les oeufs et le poulet - mais les mécanismes qui
contingentent et régissent leur mise en marché sont parmi les plus
contraignants du Québec. L'auteur démontre de manière convaincante
à l'aide de "preuve mathématiques" que c'est impossible pour cette
ferme spécifiquement d'être économiquement viable dans le contexte
législatif actuel. Les raisons principales sont les prix prohibitifs des
quotas, les minimums de quotas, les ententes de prix convenus entre l'UPA
et les acheteurs et, si ce n'est pas assez, la cotisation obligatoire
à l'UPA. Il existe cependant des brèches: le petit producteur qui
détient 300 pondeuses ou moins peut encore classes lui-même ses oeufs
sans enregistrer son poste de classement. Quoi qu'il en soit, Dominic
nous met en garde que le climat de l'agriculture au Québec n'est pas
favorable pour le producteur indépendant.

En expliquant la genèse de la ferme impossible, Dominic décrit
les nombreux intervenants qui constituent l'agriculture au Québec
aujourd'hui. Ce n'est pas évident de connaître les principaux
intervenants et de comprendre les relations entre eux alors voici un
(pas très) bref survol:

* L'Union des producteurs agricoles (UPA) - autrefois l'Union des
  cultivateurs catholiques (UCC) - est un syndicat dont la mission est
  de promouvoir les intérêts des agriculteurs au Québec. En fait,
  c'est le seul syndicat accrédité en vertu de la Loi des marchés
  agricoles du Québec auquel les agriculteurs de la province ont des
  obligations légales dont payer leur cotisation annuelle. En échange,
  les agriculteurs ont droit au remboursement d'une partie de leurs taxes
  foncières liant de la sorte un programme public (taxes et impôts)
  aux exigences d'un organisme non étatique (l'UPA).
* La Régie des marchés agricoles et alimentaires (RMAAQ, souvent
  appelé simplement "la Régie") est le tribunal de la mise en
  marché collective. C'est devant elle qu'on traîne les cultivateurs
  récalcitrants qui ne voudraient pas obtempérer aux réglements des
  membres de l'UPA. Seul un juge de la Cour d'appel, le plus haut tribunal
  du Québec, peut casser un jugement de la Régie.
* Le plan conjoint à extension juridique - pas un organisme mais digne
  de mention - est une liste de conditions de production et de mise en
  marché. Un plan conjoint est établi par au moins 10 producteurs et
  la Régie donnera force de loi au plan si le tiers des "producteurs
  intéressés" y consentent. Ensuite, tous les producteurs québecois
  actuels et futurs seront soumis à ce plan.
* Le contingentement ou système de quotas - qui découlent des plans
  conjoints - sont des "parts de production" distribués gratuitement au
  départ entre producteurs établis. Ces quotas acquièrent rapidement
  une importante valeur marchande car il n'existe pratiquement pas de
  quotas "libres" ou "à vendre". Pour une ferme laitière, par exemple,
  son quota représente 60% de sa valeur marchande soit 1.5M$ de quotas
  uniquement sur 2.5M$ de valeur totale.
* L'Office des producteurs (aussi appelé "l'Office") est l'agence
  de mise en marché accrédité pour voir à l'application du plan
  conjoint. Autrefois géré par l'État, la Loi des machés agricoles
  confie maintenant cette tâche à des fédérations d'entrepreneurs
  privés. Pour assurer son financement, l'Office est autorisé par la
  loi de percevoir des cotisations et des contributions à même les
  recettes des ventes de ses membres - qui, rappelons-le, n'ont pas le
  choix d'être membre.
* Les fédérations spécialisés auxquels un agriculteur québecois
  devra rendre des comptes selon le produit et sa transformation qui sera
  mis en marché. Par exemple, pour mettre en marché un pâté au poulet
  maison il faudrait avoir affaire à sept fédérations différentes, à
  leurs sept plans conjoints et à leurs sept offices de mise en marché
  qui seraient libres de contrôler la production, la transformation et
  la mise en marché.
* La gestion de l'offre - qui concerne seulement quelques produits -
  est un ensemble de mécanismes protectionnistes pour la mise en marché
  de produits agricoles canadiens qui repose sur trois éléments: le
  contrôle de la production, la détermination des prix et le contrôle
  des importations. Les prix sont fixés en fonction des producteurs actuels
  alors il devient impossible pour un candidat à la relève de rentabiliser
  une ferme qui doit aussi acheter un quota à sa valeur marchande.
* Le Ministère de l'agriculture, des pêcheries et de l'alimentation du
  Québec (MAPAQ) contrôle essentiellement la transformation des aliments
  tandis que l'UPA contrôle la production. Autrefois, le MAPAQ agissait
  comme chef de file en matière de diffusion du savoir-faire. Aujourd'hui,
  le Ministère a comme principale fonction la visite surprise pour chercher
  des infractions sous couvert de protéger la santé publique.

Dominic poursuit avec quelques rapports qui portent une réflexion
profonde sur l'avenir de l'agriculture et de l'agroalimentaire québecois
ainsi que quelques politiques tout aussi infructueuses:

* Le rapport Pronovost (2006) constitue LE guide de référence
  pour amorcer un virage pour "une agriculture moderne, novatrice et
  entrepreneuriale". Le rapport démontre aussi les centaines de millions de
  dollars prélevés de nos taxes et nos impôts qui sont nécessaires pour
  maintenir le système actuel à flot. Dix ans plus tard, la réponse à
  la plupart des recommandations du rapport est décrite comme "décevante"
  par Jean Pronovost lors d'une entrevue avec Le Devoir.
* Le rapport Saint-Pierre (2009), intitulé Une nouvelle génération
  de programmes de soutien financier à l'agriculture, remet surtout
  en cause l'Assurance stabilisation des revenus agricoles (ASRA). Le
  programme oriente le choix de l'agriculteur qui est fortement incité
  à se concentrer sur les productions "stabilisées" où les risques
  sont assumés aux deux tiers par le gouvernement. Ainsi, l'agriculteur
  trop bien assuré adopte une attitude de salarié plutôt que celle
  d'un entrepreneur. Cette recommandation est aussi ignorée par l'UPA,
  le statut quo étant élevé au plus haut rang de vérité absolue.
* Le livre vert pour une politique bioalimentaire (2011), intitulé
  Donner le goût du Québec, dit essentiellement que l'État a abandonné
  l'agriculture aux agriculteurs et les agriculteurs à l'UPA.
* La politique de souveraineté alimentaire (2013) est une parodie
  de politique agricole. Le gouvernement parle de "préserver
  notre garde-manger collectif" tandis qu'il n'est pas dans un état
  enviable. Il parle aussi de "développer notre vaste territoire" ce qui
  est pratiquement impossible dans le câdre législatif actuel. Cette
  politique est une coquille vide car le gouvernement ne propose aucun
  changement: ne rien changer pour ne pas déplaire.

Au bout du compte, il est important de se rappeler que la réalite de
Dominic n'est pas nécessairement la nôtre. Cependant, pour ceux qui
vivent au Québec, nous partagerons probablement quelques réalités si
nous voulons se lancer en agriculture artisanale - à taille humaine. Il
serait donc judicieux d'au moins prendre ses conseils en considération.
